@@ -2,6 +2,9 @@
 #ifndef _DISK_IDE_H
 #define _DISK_IDE_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 // not all of these are defined in previous Linux includes
 #ifndef IDE_DRIVE_TASK_NO_DATA
@@ -70,4 +73,8 @@ void set_max (int fd, uint64_t addr);
 #define IDE_SECTOR_OFFSET 3
 #endif
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
