@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2007/12/20 20:32:38 $
+ * $Date: 2008/02/08 03:10:11 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2007 Brian Carrier.  All rights reserved
@@ -245,8 +245,17 @@ tsk_hdb_idxinitialize(TSK_HDB_INFO * hdb_info, TSK_TCHAR * htype)
 uint8_t
 tsk_hdb_idxaddentry(TSK_HDB_INFO * hdb_info, char *hvalue, TSK_OFF_T offset)
 {
+    int i;
+    // make the hashes all upper case
+    for (i = 0; hvalue[i] != '\0'; i++)  {
+        if (islower((int)hvalue[i]))
+            fprintf(hdb_info->hIdxTmp, "%c", toupper((int)hvalue[i]));
+        else
+            fprintf(hdb_info->hIdxTmp, "%c", hvalue[i]);
+    }
+
     /* Print the entry to the unsorted index file */
-    fprintf(hdb_info->hIdxTmp, "%s|%.16llu\n", hvalue,
+    fprintf(hdb_info->hIdxTmp, "|%.16llu\n",
             (unsigned long long) offset);
 
     return 0;
