@@ -6,17 +6,18 @@
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005-1007 Brian Carrier.  All rights reserved 
  */
- 
+
 /** \file aff.h
  * Header files for AFF-specific data structures and functions. 
  */
- 
+
 #ifndef _AFF_H
 #define _AFF_H
 
 #if HAVE_LIBAFFLIB
 
-#include <afflib.h>
+#include <afflib/afflib.h>
+#include <afflib/afflib_i.h>
 
 extern TSK_IMG_INFO *aff_open(const char **, TSK_IMG_INFO *);
 
