@@ -10,11 +10,11 @@
  * Based on raw image support of the Sleuth Kit from
  * Brian Carrier.
  */
- 
+
 /** \file ewf.h
  * Header files for EWF-specific data structures and functions. 
  */
- 
+
 #ifndef _EWF_H
 #define _EWF_H
 
@@ -25,13 +25,12 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-
     extern TSK_IMG_INFO *ewf_open(int, const char **, TSK_IMG_INFO *);
-    
-    typedef struct  {
+
+    typedef struct {
         TSK_IMG_INFO img_info;
         LIBEWF_HANDLE *handle;
-        char md5hash[LIBEWF_STRING_DIGEST_HASH_LENGTH_MD5];
+        char md5hash[33];
         int md5hash_isset;
     } IMG_EWF_INFO;
 
